PyBaccarat: tests.test_hand.TestHand Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | List of all members
tests.test_hand.TestHand Class Reference
Inheritance diagram for tests.test_hand.TestHand:

## Public Member Functions
def | test_constructor (self)
def | test_empty (self)
def | test_add (self)
def | test_value (self)
def | test_need_hit (self)
def | test_get_card (self)
def | test_str (self)

## Detailed Description

    Unit test for the baccarat.Hand class.

## Member Function Documentation

## ◆ test_add()

def tests.test_hand.TestHand.test_add | ( |  | self | ) |

    add(card)

## ◆ test_constructor()

def tests.test_hand.TestHand.test_constructor | ( |  | self | ) |

    test hand construction

## ◆ test_empty()

def tests.test_hand.TestHand.test_empty | ( |  | self | ) |

    test empty method

## ◆ test_get_card()

def tests.test_hand.TestHand.test_get_card | ( |  | self | ) |

    get_card(int)

## ◆ test_need_hit()

def tests.test_hand.TestHand.test_need_hit | ( |  | self | ) |

    need_hit()
    need_hit(player)

The documentation for this class was generated from the following file:

- tests/test_hand.py